ESCMID: News & Discussion
Author: ESCMID - European Society of Clinical Microbiology and Infectious Diseases 2008
Description: News and information in Clinical Microbiology and Infectious Diseases, including position papers, discussion documents and what is happening at ESCMID
Keywords: News,online,media,discussion,documents,papers

- Home
- Contact
- Sitemap
- Forum

Follow ESCMID on

## News & Discussion

- News
- ESCMID Newsletter
- Press releases
- @Press room
- Discussion forum
- Archive

# News & Discussion

Your direct link to all sorts of news and information in the infection fields - position papers, press releases, and news on what is happening at ESCMID, including the online ESCMID Newsletter and opinion poll results.

### News

Here you will find the latest news from the Society and considered of interest to our visitors.

### ESCMID Newsletter

Includes the most recent happenings in the Society, this newsletter is sent each week to ESCMID regular and affiliated members and collaborators. Also features calls ...

### Press releases

Vienna, October 27: Delegates at a major international conference held in Vienna last week and convened by the European Society of Clinical Microbiology and ...

### @Press room

Journalists can find out about the society's press activities and find important contact information.

### Discussion forum

The purpose of this discussion forum is to provide a platform for debates and comments on topics related to our Society.

### Archive

Here you will find past society news.

Recommend page
Login
Login
Forgot password
Registration
Search
ESCMID Newsletter Sign Up
Sign Up

# ESCMID Library

Find: Clinical Microbiology and Infection (CMI), New Microbes & New Infections (NMNI), medical guidelines, ESCMID Yearbook, Online Lecture Library, Reports & links.